# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MaintenanceRun(object):
    """
    Details of a maintenance run.
    """

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "SCHEDULED"
    LIFECYCLE_STATE_SCHEDULED = "SCHEDULED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "SKIPPED"
    LIFECYCLE_STATE_SKIPPED = "SKIPPED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a MaintenanceRun.
    #: This constant has a value of "CANCELED"
    LIFECYCLE_STATE_CANCELED = "CANCELED"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRun.
    #: This constant has a value of "AUTONOMOUS_EXADATA_INFRASTRUCTURE"
    TARGET_RESOURCE_TYPE_AUTONOMOUS_EXADATA_INFRASTRUCTURE = "AUTONOMOUS_EXADATA_INFRASTRUCTURE"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRun.
    #: This constant has a value of "AUTONOMOUS_CONTAINER_DATABASE"
    TARGET_RESOURCE_TYPE_AUTONOMOUS_CONTAINER_DATABASE = "AUTONOMOUS_CONTAINER_DATABASE"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRun.
    #: This constant has a value of "EXADATA_DB_SYSTEM"
    TARGET_RESOURCE_TYPE_EXADATA_DB_SYSTEM = "EXADATA_DB_SYSTEM"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRun.
    #: This constant has a value of "CLOUD_EXADATA_INFRASTRUCTURE"
    TARGET_RESOURCE_TYPE_CLOUD_EXADATA_INFRASTRUCTURE = "CLOUD_EXADATA_INFRASTRUCTURE"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRun.
    #: This constant has a value of "EXACC_INFRASTRUCTURE"
    TARGET_RESOURCE_TYPE_EXACC_INFRASTRUCTURE = "EXACC_INFRASTRUCTURE"

    #: A constant which can be used with the target_resource_type property of a MaintenanceRun.
    #: This constant has a value of "AUTONOMOUS_DATABASE"
    TARGET_RESOURCE_TYPE_AUTONOMOUS_DATABASE = "AUTONOMOUS_DATABASE"

    #: A constant which can be used with the maintenance_type property of a MaintenanceRun.
    #: This constant has a value of "PLANNED"
    MAINTENANCE_TYPE_PLANNED = "PLANNED"

    #: A constant which can be used with the maintenance_type property of a MaintenanceRun.
    #: This constant has a value of "UNPLANNED"
    MAINTENANCE_TYPE_UNPLANNED = "UNPLANNED"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRun.
    #: This constant has a value of "QUARTERLY"
    MAINTENANCE_SUBTYPE_QUARTERLY = "QUARTERLY"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRun.
    #: This constant has a value of "HARDWARE"
    MAINTENANCE_SUBTYPE_HARDWARE = "HARDWARE"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRun.
    #: This constant has a value of "CRITICAL"
    MAINTENANCE_SUBTYPE_CRITICAL = "CRITICAL"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRun.
    #: This constant has a value of "INFRASTRUCTURE"
    MAINTENANCE_SUBTYPE_INFRASTRUCTURE = "INFRASTRUCTURE"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRun.
    #: This constant has a value of "DATABASE"
    MAINTENANCE_SUBTYPE_DATABASE = "DATABASE"

    #: A constant which can be used with the maintenance_subtype property of a MaintenanceRun.
    #: This constant has a value of "ONEOFF"
    MAINTENANCE_SUBTYPE_ONEOFF = "ONEOFF"

    #: A constant which can be used with the patching_mode property of a MaintenanceRun.
    #: This constant has a value of "ROLLING"
    PATCHING_MODE_ROLLING = "ROLLING"

    #: A constant which can be used with the patching_mode property of a MaintenanceRun.
    #: This constant has a value of "NONROLLING"
    PATCHING_MODE_NONROLLING = "NONROLLING"

    def __init__(self, **kwargs):
        """
        Initializes a new MaintenanceRun object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this MaintenanceRun.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this MaintenanceRun.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this MaintenanceRun.
        :type display_name: str

        :param description:
            The value to assign to the description property of this MaintenanceRun.
        :type description: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this MaintenanceRun.
            Allowed values for this property are: "SCHEDULED", "IN_PROGRESS", "SUCCEEDED", "SKIPPED", "FAILED", "UPDATING", "DELETING", "DELETED", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this MaintenanceRun.
        :type lifecycle_details: str

        :param time_scheduled:
            The value to assign to the time_scheduled property of this MaintenanceRun.
        :type time_scheduled: datetime

        :param time_started:
            The value to assign to the time_started property of this MaintenanceRun.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this MaintenanceRun.
        :type time_ended: datetime

        :param target_resource_type:
            The value to assign to the target_resource_type property of this MaintenanceRun.
            Allowed values for this property are: "AUTONOMOUS_EXADATA_INFRASTRUCTURE", "AUTONOMOUS_CONTAINER_DATABASE", "EXADATA_DB_SYSTEM", "CLOUD_EXADATA_INFRASTRUCTURE", "EXACC_INFRASTRUCTURE", "AUTONOMOUS_DATABASE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type target_resource_type: str

        :param target_resource_id:
            The value to assign to the target_resource_id property of this MaintenanceRun.
        :type target_resource_id: str

        :param maintenance_type:
            The value to assign to the maintenance_type property of this MaintenanceRun.
            Allowed values for this property are: "PLANNED", "UNPLANNED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type maintenance_type: str

        :param patch_id:
            The value to assign to the patch_id property of this MaintenanceRun.
        :type patch_id: str

        :param maintenance_subtype:
            The value to assign to the maintenance_subtype property of this MaintenanceRun.
            Allowed values for this property are: "QUARTERLY", "HARDWARE", "CRITICAL", "INFRASTRUCTURE", "DATABASE", "ONEOFF", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type maintenance_subtype: str

        :param peer_maintenance_run_id:
            The value to assign to the peer_maintenance_run_id property of this MaintenanceRun.
        :type peer_maintenance_run_id: str

        :param patching_mode:
            The value to assign to the patching_mode property of this MaintenanceRun.
            Allowed values for this property are: "ROLLING", "NONROLLING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type patching_mode: str

        :param patch_failure_count:
            The value to assign to the patch_failure_count property of this MaintenanceRun.
        :type patch_failure_count: int

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_scheduled': 'datetime',
            'time_started': 'datetime',
            'time_ended': 'datetime',
            'target_resource_type': 'str',
            'target_resource_id': 'str',
            'maintenance_type': 'str',
            'patch_id': 'str',
            'maintenance_subtype': 'str',
            'peer_maintenance_run_id': 'str',
            'patching_mode': 'str',
            'patch_failure_count': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_scheduled': 'timeScheduled',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded',
            'target_resource_type': 'targetResourceType',
            'target_resource_id': 'targetResourceId',
            'maintenance_type': 'maintenanceType',
            'patch_id': 'patchId',
            'maintenance_subtype': 'maintenanceSubtype',
            'peer_maintenance_run_id': 'peerMaintenanceRunId',
            'patching_mode': 'patchingMode',
            'patch_failure_count': 'patchFailureCount'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_scheduled = None
        self._time_started = None
        self._time_ended = None
        self._target_resource_type = None
        self._target_resource_id = None
        self._maintenance_type = None
        self._patch_id = None
        self._maintenance_subtype = None
        self._peer_maintenance_run_id = None
        self._patching_mode = None
        self._patch_failure_count = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this MaintenanceRun.
        The OCID of the maintenance run.


        :return: The id of this MaintenanceRun.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MaintenanceRun.
        The OCID of the maintenance run.


        :param id: The id of this MaintenanceRun.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this MaintenanceRun.
        The OCID of the compartment.


        :return: The compartment_id of this MaintenanceRun.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this MaintenanceRun.
        The OCID of the compartment.


        :param compartment_id: The compartment_id of this MaintenanceRun.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this MaintenanceRun.
        The user-friendly name for the maintenance run.


        :return: The display_name of this MaintenanceRun.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this MaintenanceRun.
        The user-friendly name for the maintenance run.


        :param display_name: The display_name of this MaintenanceRun.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this MaintenanceRun.
        Description of the maintenance run.


        :return: The description of this MaintenanceRun.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this MaintenanceRun.
        Description of the maintenance run.


        :param description: The description of this MaintenanceRun.
        :type: str
        """
        self._description = description

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this MaintenanceRun.
        The current state of the maintenance run. For Autonomous Database on shared Exadata infrastructure, valid states are IN_PROGRESS, SUCCEEDED and FAILED.

        Allowed values for this property are: "SCHEDULED", "IN_PROGRESS", "SUCCEEDED", "SKIPPED", "FAILED", "UPDATING", "DELETING", "DELETED", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this MaintenanceRun.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this MaintenanceRun.
        The current state of the maintenance run. For Autonomous Database on shared Exadata infrastructure, valid states are IN_PROGRESS, SUCCEEDED and FAILED.


        :param lifecycle_state: The lifecycle_state of this MaintenanceRun.
        :type: str
        """
        allowed_values = ["SCHEDULED", "IN_PROGRESS", "SUCCEEDED", "SKIPPED", "FAILED", "UPDATING", "DELETING", "DELETED", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this MaintenanceRun.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this MaintenanceRun.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this MaintenanceRun.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this MaintenanceRun.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_scheduled(self):
        """
        **[Required]** Gets the time_scheduled of this MaintenanceRun.
        The date and time the maintenance run is scheduled to occur.


        :return: The time_scheduled of this MaintenanceRun.
        :rtype: datetime
        """
        return self._time_scheduled

    @time_scheduled.setter
    def time_scheduled(self, time_scheduled):
        """
        Sets the time_scheduled of this MaintenanceRun.
        The date and time the maintenance run is scheduled to occur.


        :param time_scheduled: The time_scheduled of this MaintenanceRun.
        :type: datetime
        """
        self._time_scheduled = time_scheduled

    @property
    def time_started(self):
        """
        Gets the time_started of this MaintenanceRun.
        The date and time the maintenance run starts.


        :return: The time_started of this MaintenanceRun.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this MaintenanceRun.
        The date and time the maintenance run starts.


        :param time_started: The time_started of this MaintenanceRun.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        Gets the time_ended of this MaintenanceRun.
        The date and time the maintenance run was completed.


        :return: The time_ended of this MaintenanceRun.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this MaintenanceRun.
        The date and time the maintenance run was completed.


        :param time_ended: The time_ended of this MaintenanceRun.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def target_resource_type(self):
        """
        Gets the target_resource_type of this MaintenanceRun.
        The type of the target resource on which the maintenance run occurs.

        Allowed values for this property are: "AUTONOMOUS_EXADATA_INFRASTRUCTURE", "AUTONOMOUS_CONTAINER_DATABASE", "EXADATA_DB_SYSTEM", "CLOUD_EXADATA_INFRASTRUCTURE", "EXACC_INFRASTRUCTURE", "AUTONOMOUS_DATABASE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The target_resource_type of this MaintenanceRun.
        :rtype: str
        """
        return self._target_resource_type

    @target_resource_type.setter
    def target_resource_type(self, target_resource_type):
        """
        Sets the target_resource_type of this MaintenanceRun.
        The type of the target resource on which the maintenance run occurs.


        :param target_resource_type: The target_resource_type of this MaintenanceRun.
        :type: str
        """
        allowed_values = ["AUTONOMOUS_EXADATA_INFRASTRUCTURE", "AUTONOMOUS_CONTAINER_DATABASE", "EXADATA_DB_SYSTEM", "CLOUD_EXADATA_INFRASTRUCTURE", "EXACC_INFRASTRUCTURE", "AUTONOMOUS_DATABASE"]
        if not value_allowed_none_or_none_sentinel(target_resource_type, allowed_values):
            target_resource_type = 'UNKNOWN_ENUM_VALUE'
        self._target_resource_type = target_resource_type

    @property
    def target_resource_id(self):
        """
        Gets the target_resource_id of this MaintenanceRun.
        The ID of the target resource on which the maintenance run occurs.


        :return: The target_resource_id of this MaintenanceRun.
        :rtype: str
        """
        return self._target_resource_id

    @target_resource_id.setter
    def target_resource_id(self, target_resource_id):
        """
        Sets the target_resource_id of this MaintenanceRun.
        The ID of the target resource on which the maintenance run occurs.


        :param target_resource_id: The target_resource_id of this MaintenanceRun.
        :type: str
        """
        self._target_resource_id = target_resource_id

    @property
    def maintenance_type(self):
        """
        Gets the maintenance_type of this MaintenanceRun.
        Maintenance type.

        Allowed values for this property are: "PLANNED", "UNPLANNED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The maintenance_type of this MaintenanceRun.
        :rtype: str
        """
        return self._maintenance_type

    @maintenance_type.setter
    def maintenance_type(self, maintenance_type):
        """
        Sets the maintenance_type of this MaintenanceRun.
        Maintenance type.


        :param maintenance_type: The maintenance_type of this MaintenanceRun.
        :type: str
        """
        allowed_values = ["PLANNED", "UNPLANNED"]
        if not value_allowed_none_or_none_sentinel(maintenance_type, allowed_values):
            maintenance_type = 'UNKNOWN_ENUM_VALUE'
        self._maintenance_type = maintenance_type

    @property
    def patch_id(self):
        """
        Gets the patch_id of this MaintenanceRun.
        The unique identifier of the patch. The identifier string includes the patch type, the Oracle Database version, and the patch creation date (using the format YYMMDD). For example, the identifier `ru_patch_19.9.0.0_201030` is used for an RU patch for Oracle Database 19.9.0.0 that was released October 30, 2020.


        :return: The patch_id of this MaintenanceRun.
        :rtype: str
        """
        return self._patch_id

    @patch_id.setter
    def patch_id(self, patch_id):
        """
        Sets the patch_id of this MaintenanceRun.
        The unique identifier of the patch. The identifier string includes the patch type, the Oracle Database version, and the patch creation date (using the format YYMMDD). For example, the identifier `ru_patch_19.9.0.0_201030` is used for an RU patch for Oracle Database 19.9.0.0 that was released October 30, 2020.


        :param patch_id: The patch_id of this MaintenanceRun.
        :type: str
        """
        self._patch_id = patch_id

    @property
    def maintenance_subtype(self):
        """
        Gets the maintenance_subtype of this MaintenanceRun.
        Maintenance sub-type.

        Allowed values for this property are: "QUARTERLY", "HARDWARE", "CRITICAL", "INFRASTRUCTURE", "DATABASE", "ONEOFF", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The maintenance_subtype of this MaintenanceRun.
        :rtype: str
        """
        return self._maintenance_subtype

    @maintenance_subtype.setter
    def maintenance_subtype(self, maintenance_subtype):
        """
        Sets the maintenance_subtype of this MaintenanceRun.
        Maintenance sub-type.


        :param maintenance_subtype: The maintenance_subtype of this MaintenanceRun.
        :type: str
        """
        allowed_values = ["QUARTERLY", "HARDWARE", "CRITICAL", "INFRASTRUCTURE", "DATABASE", "ONEOFF"]
        if not value_allowed_none_or_none_sentinel(maintenance_subtype, allowed_values):
            maintenance_subtype = 'UNKNOWN_ENUM_VALUE'
        self._maintenance_subtype = maintenance_subtype

    @property
    def peer_maintenance_run_id(self):
        """
        Gets the peer_maintenance_run_id of this MaintenanceRun.
        The `OCID`__ of the maintenance run for the Autonomous Data Guard association's peer container database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The peer_maintenance_run_id of this MaintenanceRun.
        :rtype: str
        """
        return self._peer_maintenance_run_id

    @peer_maintenance_run_id.setter
    def peer_maintenance_run_id(self, peer_maintenance_run_id):
        """
        Sets the peer_maintenance_run_id of this MaintenanceRun.
        The `OCID`__ of the maintenance run for the Autonomous Data Guard association's peer container database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param peer_maintenance_run_id: The peer_maintenance_run_id of this MaintenanceRun.
        :type: str
        """
        self._peer_maintenance_run_id = peer_maintenance_run_id

    @property
    def patching_mode(self):
        """
        Gets the patching_mode of this MaintenanceRun.
        Cloud Exadata infrastructure node patching method, either \"ROLLING\" or \"NONROLLING\". Default value is ROLLING.

        *IMPORTANT*: Non-rolling infrastructure patching involves system down time. See `Oracle-Managed Infrastructure Maintenance Updates`__ for more information.

        __ https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/examaintenance.htm#Oracle

        Allowed values for this property are: "ROLLING", "NONROLLING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The patching_mode of this MaintenanceRun.
        :rtype: str
        """
        return self._patching_mode

    @patching_mode.setter
    def patching_mode(self, patching_mode):
        """
        Sets the patching_mode of this MaintenanceRun.
        Cloud Exadata infrastructure node patching method, either \"ROLLING\" or \"NONROLLING\". Default value is ROLLING.

        *IMPORTANT*: Non-rolling infrastructure patching involves system down time. See `Oracle-Managed Infrastructure Maintenance Updates`__ for more information.

        __ https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/examaintenance.htm#Oracle


        :param patching_mode: The patching_mode of this MaintenanceRun.
        :type: str
        """
        allowed_values = ["ROLLING", "NONROLLING"]
        if not value_allowed_none_or_none_sentinel(patching_mode, allowed_values):
            patching_mode = 'UNKNOWN_ENUM_VALUE'
        self._patching_mode = patching_mode

    @property
    def patch_failure_count(self):
        """
        Gets the patch_failure_count of this MaintenanceRun.
        Contain the patch failure count.


        :return: The patch_failure_count of this MaintenanceRun.
        :rtype: int
        """
        return self._patch_failure_count

    @patch_failure_count.setter
    def patch_failure_count(self, patch_failure_count):
        """
        Sets the patch_failure_count of this MaintenanceRun.
        Contain the patch failure count.


        :param patch_failure_count: The patch_failure_count of this MaintenanceRun.
        :type: int
        """
        self._patch_failure_count = patch_failure_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseConnectionStringProfile(object):
    """
    The connection string profile to allow clients to group, filter and select connection string values based on structured metadata.
    """

    #: A constant which can be used with the consumer_group property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "HIGH"
    CONSUMER_GROUP_HIGH = "HIGH"

    #: A constant which can be used with the consumer_group property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "MEDIUM"
    CONSUMER_GROUP_MEDIUM = "MEDIUM"

    #: A constant which can be used with the consumer_group property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "LOW"
    CONSUMER_GROUP_LOW = "LOW"

    #: A constant which can be used with the consumer_group property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "TP"
    CONSUMER_GROUP_TP = "TP"

    #: A constant which can be used with the consumer_group property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "TPURGENT"
    CONSUMER_GROUP_TPURGENT = "TPURGENT"

    #: A constant which can be used with the protocol property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "TCP"
    PROTOCOL_TCP = "TCP"

    #: A constant which can be used with the protocol property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "TCPS"
    PROTOCOL_TCPS = "TCPS"

    #: A constant which can be used with the tls_authentication property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "SERVER"
    TLS_AUTHENTICATION_SERVER = "SERVER"

    #: A constant which can be used with the tls_authentication property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "MUTUAL"
    TLS_AUTHENTICATION_MUTUAL = "MUTUAL"

    #: A constant which can be used with the host_format property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "FQDN"
    HOST_FORMAT_FQDN = "FQDN"

    #: A constant which can be used with the host_format property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "IP"
    HOST_FORMAT_IP = "IP"

    #: A constant which can be used with the session_mode property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "DIRECT"
    SESSION_MODE_DIRECT = "DIRECT"

    #: A constant which can be used with the session_mode property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "REDIRECT"
    SESSION_MODE_REDIRECT = "REDIRECT"

    #: A constant which can be used with the syntax_format property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "LONG"
    SYNTAX_FORMAT_LONG = "LONG"

    #: A constant which can be used with the syntax_format property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "EZCONNECT"
    SYNTAX_FORMAT_EZCONNECT = "EZCONNECT"

    #: A constant which can be used with the syntax_format property of a DatabaseConnectionStringProfile.
    #: This constant has a value of "EZCONNECTPLUS"
    SYNTAX_FORMAT_EZCONNECTPLUS = "EZCONNECTPLUS"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseConnectionStringProfile object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this DatabaseConnectionStringProfile.
        :type display_name: str

        :param value:
            The value to assign to the value property of this DatabaseConnectionStringProfile.
        :type value: str

        :param consumer_group:
            The value to assign to the consumer_group property of this DatabaseConnectionStringProfile.
            Allowed values for this property are: "HIGH", "MEDIUM", "LOW", "TP", "TPURGENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type consumer_group: str

        :param protocol:
            The value to assign to the protocol property of this DatabaseConnectionStringProfile.
            Allowed values for this property are: "TCP", "TCPS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type protocol: str

        :param tls_authentication:
            The value to assign to the tls_authentication property of this DatabaseConnectionStringProfile.
            Allowed values for this property are: "SERVER", "MUTUAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type tls_authentication: str

        :param host_format:
            The value to assign to the host_format property of this DatabaseConnectionStringProfile.
            Allowed values for this property are: "FQDN", "IP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type host_format: str

        :param session_mode:
            The value to assign to the session_mode property of this DatabaseConnectionStringProfile.
            Allowed values for this property are: "DIRECT", "REDIRECT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type session_mode: str

        :param syntax_format:
            The value to assign to the syntax_format property of this DatabaseConnectionStringProfile.
            Allowed values for this property are: "LONG", "EZCONNECT", "EZCONNECTPLUS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type syntax_format: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'value': 'str',
            'consumer_group': 'str',
            'protocol': 'str',
            'tls_authentication': 'str',
            'host_format': 'str',
            'session_mode': 'str',
            'syntax_format': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'value': 'value',
            'consumer_group': 'consumerGroup',
            'protocol': 'protocol',
            'tls_authentication': 'tlsAuthentication',
            'host_format': 'hostFormat',
            'session_mode': 'sessionMode',
            'syntax_format': 'syntaxFormat'
        }

        self._display_name = None
        self._value = None
        self._consumer_group = None
        self._protocol = None
        self._tls_authentication = None
        self._host_format = None
        self._session_mode = None
        self._syntax_format = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DatabaseConnectionStringProfile.
        A user-friendly name for the connection.


        :return: The display_name of this DatabaseConnectionStringProfile.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DatabaseConnectionStringProfile.
        A user-friendly name for the connection.


        :param display_name: The display_name of this DatabaseConnectionStringProfile.
        :type: str
        """
        self._display_name = display_name

    @property
    def value(self):
        """
        **[Required]** Gets the value of this DatabaseConnectionStringProfile.
        Connection string value.


        :return: The value of this DatabaseConnectionStringProfile.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this DatabaseConnectionStringProfile.
        Connection string value.


        :param value: The value of this DatabaseConnectionStringProfile.
        :type: str
        """
        self._value = value

    @property
    def consumer_group(self):
        """
        Gets the consumer_group of this DatabaseConnectionStringProfile.
        Consumer group used by the connection.

        Allowed values for this property are: "HIGH", "MEDIUM", "LOW", "TP", "TPURGENT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The consumer_group of this DatabaseConnectionStringProfile.
        :rtype: str
        """
        return self._consumer_group

    @consumer_group.setter
    def consumer_group(self, consumer_group):
        """
        Sets the consumer_group of this DatabaseConnectionStringProfile.
        Consumer group used by the connection.


        :param consumer_group: The consumer_group of this DatabaseConnectionStringProfile.
        :type: str
        """
        allowed_values = ["HIGH", "MEDIUM", "LOW", "TP", "TPURGENT"]
        if not value_allowed_none_or_none_sentinel(consumer_group, allowed_values):
            consumer_group = 'UNKNOWN_ENUM_VALUE'
        self._consumer_group = consumer_group

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this DatabaseConnectionStringProfile.
        Protocol used by the connection.

        Allowed values for this property are: "TCP", "TCPS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The protocol of this DatabaseConnectionStringProfile.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this DatabaseConnectionStringProfile.
        Protocol used by the connection.


        :param protocol: The protocol of this DatabaseConnectionStringProfile.
        :type: str
        """
        allowed_values = ["TCP", "TCPS"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            protocol = 'UNKNOWN_ENUM_VALUE'
        self._protocol = protocol

    @property
    def tls_authentication(self):
        """
        Gets the tls_authentication of this DatabaseConnectionStringProfile.
        Specifies whether the TLS handshake is using one-way (`SERVER`) or mutual (`MUTUAL`) authentication.

        Allowed values for this property are: "SERVER", "MUTUAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The tls_authentication of this DatabaseConnectionStringProfile.
        :rtype: str
        """
        return self._tls_authentication

    @tls_authentication.setter
    def tls_authentication(self, tls_authentication):
        """
        Sets the tls_authentication of this DatabaseConnectionStringProfile.
        Specifies whether the TLS handshake is using one-way (`SERVER`) or mutual (`MUTUAL`) authentication.


        :param tls_authentication: The tls_authentication of this DatabaseConnectionStringProfile.
        :type: str
        """
        allowed_values = ["SERVER", "MUTUAL"]
        if not value_allowed_none_or_none_sentinel(tls_authentication, allowed_values):
            tls_authentication = 'UNKNOWN_ENUM_VALUE'
        self._tls_authentication = tls_authentication

    @property
    def host_format(self):
        """
        **[Required]** Gets the host_format of this DatabaseConnectionStringProfile.
        Host format used in connection string.

        Allowed values for this property are: "FQDN", "IP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The host_format of this DatabaseConnectionStringProfile.
        :rtype: str
        """
        return self._host_format

    @host_format.setter
    def host_format(self, host_format):
        """
        Sets the host_format of this DatabaseConnectionStringProfile.
        Host format used in connection string.


        :param host_format: The host_format of this DatabaseConnectionStringProfile.
        :type: str
        """
        allowed_values = ["FQDN", "IP"]
        if not value_allowed_none_or_none_sentinel(host_format, allowed_values):
            host_format = 'UNKNOWN_ENUM_VALUE'
        self._host_format = host_format

    @property
    def session_mode(self):
        """
        **[Required]** Gets the session_mode of this DatabaseConnectionStringProfile.
        Specifies whether the listener performs a direct hand-off of the session, or redirects the session. In RAC deployments where SCAN is used, sessions are redirected to a Node VIP. Use `DIRECT` for direct hand-offs. Use `REDIRECT` to redirect the session.

        Allowed values for this property are: "DIRECT", "REDIRECT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The session_mode of this DatabaseConnectionStringProfile.
        :rtype: str
        """
        return self._session_mode

    @session_mode.setter
    def session_mode(self, session_mode):
        """
        Sets the session_mode of this DatabaseConnectionStringProfile.
        Specifies whether the listener performs a direct hand-off of the session, or redirects the session. In RAC deployments where SCAN is used, sessions are redirected to a Node VIP. Use `DIRECT` for direct hand-offs. Use `REDIRECT` to redirect the session.


        :param session_mode: The session_mode of this DatabaseConnectionStringProfile.
        :type: str
        """
        allowed_values = ["DIRECT", "REDIRECT"]
        if not value_allowed_none_or_none_sentinel(session_mode, allowed_values):
            session_mode = 'UNKNOWN_ENUM_VALUE'
        self._session_mode = session_mode

    @property
    def syntax_format(self):
        """
        **[Required]** Gets the syntax_format of this DatabaseConnectionStringProfile.
        Specifies whether the connection string is using the long (`LONG`), Easy Connect (`EZCONNECT`), or Easy Connect Plus (`EZCONNECTPLUS`) format.
        Autonomous Databases on shared Exadata infrastructure always use the long format.

        Allowed values for this property are: "LONG", "EZCONNECT", "EZCONNECTPLUS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The syntax_format of this DatabaseConnectionStringProfile.
        :rtype: str
        """
        return self._syntax_format

    @syntax_format.setter
    def syntax_format(self, syntax_format):
        """
        Sets the syntax_format of this DatabaseConnectionStringProfile.
        Specifies whether the connection string is using the long (`LONG`), Easy Connect (`EZCONNECT`), or Easy Connect Plus (`EZCONNECTPLUS`) format.
        Autonomous Databases on shared Exadata infrastructure always use the long format.


        :param syntax_format: The syntax_format of this DatabaseConnectionStringProfile.
        :type: str
        """
        allowed_values = ["LONG", "EZCONNECT", "EZCONNECTPLUS"]
        if not value_allowed_none_or_none_sentinel(syntax_format, allowed_values):
            syntax_format = 'UNKNOWN_ENUM_VALUE'
        self._syntax_format = syntax_format

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateSourceDetails(object):
    """
    You can update the authorization details to access the source environment from which you want to migrate applications to
    Oracle Cloud Infrastructure. You can also update the description and tags of a source.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateSourceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateSourceDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateSourceDetails.
        :type description: str

        :param source_details:
            The value to assign to the source_details property of this UpdateSourceDetails.
        :type source_details: oci.application_migration.models.SourceDetails

        :param authorization_details:
            The value to assign to the authorization_details property of this UpdateSourceDetails.
        :type authorization_details: oci.application_migration.models.AuthorizationDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateSourceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateSourceDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'source_details': 'SourceDetails',
            'authorization_details': 'AuthorizationDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'source_details': 'sourceDetails',
            'authorization_details': 'authorizationDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._source_details = None
        self._authorization_details = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateSourceDetails.
        Name of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.


        :return: The display_name of this UpdateSourceDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateSourceDetails.
        Name of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.


        :param display_name: The display_name of this UpdateSourceDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdateSourceDetails.
        Description of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.


        :return: The description of this UpdateSourceDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateSourceDetails.
        Description of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.


        :param description: The description of this UpdateSourceDetails.
        :type: str
        """
        self._description = description

    @property
    def source_details(self):
        """
        Gets the source_details of this UpdateSourceDetails.

        :return: The source_details of this UpdateSourceDetails.
        :rtype: oci.application_migration.models.SourceDetails
        """
        return self._source_details

    @source_details.setter
    def source_details(self, source_details):
        """
        Sets the source_details of this UpdateSourceDetails.

        :param source_details: The source_details of this UpdateSourceDetails.
        :type: oci.application_migration.models.SourceDetails
        """
        self._source_details = source_details

    @property
    def authorization_details(self):
        """
        Gets the authorization_details of this UpdateSourceDetails.

        :return: The authorization_details of this UpdateSourceDetails.
        :rtype: oci.application_migration.models.AuthorizationDetails
        """
        return self._authorization_details

    @authorization_details.setter
    def authorization_details(self, authorization_details):
        """
        Sets the authorization_details of this UpdateSourceDetails.

        :param authorization_details: The authorization_details of this UpdateSourceDetails.
        :type: oci.application_migration.models.AuthorizationDetails
        """
        self._authorization_details = authorization_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateSourceDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__. Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateSourceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateSourceDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__. Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateSourceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateSourceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__. Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateSourceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateSourceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__. Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateSourceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateSourceApplicationInfo(object):
    """
    The information about the application.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateSourceApplicationInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param workspace_id:
            The value to assign to the workspace_id property of this CreateSourceApplicationInfo.
        :type workspace_id: str

        :param application_key:
            The value to assign to the application_key property of this CreateSourceApplicationInfo.
        :type application_key: str

        """
        self.swagger_types = {
            'workspace_id': 'str',
            'application_key': 'str'
        }

        self.attribute_map = {
            'workspace_id': 'workspaceId',
            'application_key': 'applicationKey'
        }

        self._workspace_id = None
        self._application_key = None

    @property
    def workspace_id(self):
        """
        Gets the workspace_id of this CreateSourceApplicationInfo.
        The OCID of the workspace containing the application. This allows cross workspace deployment to publish an application from a different workspace into the current workspace specified in this operation.


        :return: The workspace_id of this CreateSourceApplicationInfo.
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """
        Sets the workspace_id of this CreateSourceApplicationInfo.
        The OCID of the workspace containing the application. This allows cross workspace deployment to publish an application from a different workspace into the current workspace specified in this operation.


        :param workspace_id: The workspace_id of this CreateSourceApplicationInfo.
        :type: str
        """
        self._workspace_id = workspace_id

    @property
    def application_key(self):
        """
        Gets the application_key of this CreateSourceApplicationInfo.
        The source application key to use when creating the application.


        :return: The application_key of this CreateSourceApplicationInfo.
        :rtype: str
        """
        return self._application_key

    @application_key.setter
    def application_key(self, application_key):
        """
        Sets the application_key of this CreateSourceApplicationInfo.
        The source application key to use when creating the application.


        :param application_key: The application_key of this CreateSourceApplicationInfo.
        :type: str
        """
        self._application_key = application_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RevokeAccessRequestDetails(object):
    """
    Summary of why the already approved access request was revoked.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RevokeAccessRequestDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param approver_comment:
            The value to assign to the approver_comment property of this RevokeAccessRequestDetails.
        :type approver_comment: str

        """
        self.swagger_types = {
            'approver_comment': 'str'
        }

        self.attribute_map = {
            'approver_comment': 'approverComment'
        }

        self._approver_comment = None

    @property
    def approver_comment(self):
        """
        Gets the approver_comment of this RevokeAccessRequestDetails.
        Comment specified by the approver explaining why the approval is revoked.


        :return: The approver_comment of this RevokeAccessRequestDetails.
        :rtype: str
        """
        return self._approver_comment

    @approver_comment.setter
    def approver_comment(self, approver_comment):
        """
        Sets the approver_comment of this RevokeAccessRequestDetails.
        Comment specified by the approver explaining why the approval is revoked.


        :param approver_comment: The approver_comment of this RevokeAccessRequestDetails.
        :type: str
        """
        self._approver_comment = approver_comment

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequest(object):
    """
    Many of the API requests you use to create and configure WAAS policies do not take effect immediately. In these cases, the request spawns an asynchronous work flow to fulfill the request. `WorkRequest` objects provide visibility for in-progress work flows. For more information about work requests, see `Viewing the State of a Work Request`__.

    __ https://docs.cloud.oracle.com/Content/Balance/Tasks/viewingworkrequest.htm
    """

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "CREATE_WAAS_POLICY"
    OPERATION_TYPE_CREATE_WAAS_POLICY = "CREATE_WAAS_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "UPDATE_WAAS_POLICY"
    OPERATION_TYPE_UPDATE_WAAS_POLICY = "UPDATE_WAAS_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "DELETE_WAAS_POLICY"
    OPERATION_TYPE_DELETE_WAAS_POLICY = "DELETE_WAAS_POLICY"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "CREATE_HTTP_REDIRECT"
    OPERATION_TYPE_CREATE_HTTP_REDIRECT = "CREATE_HTTP_REDIRECT"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "UPDATE_HTTP_REDIRECT"
    OPERATION_TYPE_UPDATE_HTTP_REDIRECT = "UPDATE_HTTP_REDIRECT"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "DELETE_HTTP_REDIRECT"
    OPERATION_TYPE_DELETE_HTTP_REDIRECT = "DELETE_HTTP_REDIRECT"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "PURGE_WAAS_POLICY_CACHE"
    OPERATION_TYPE_PURGE_WAAS_POLICY_CACHE = "PURGE_WAAS_POLICY_CACHE"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "CREATE_CUSTOM_PROTECTION_RULE"
    OPERATION_TYPE_CREATE_CUSTOM_PROTECTION_RULE = "CREATE_CUSTOM_PROTECTION_RULE"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "UPDATE_CUSTOM_PROTECTION_RULE"
    OPERATION_TYPE_UPDATE_CUSTOM_PROTECTION_RULE = "UPDATE_CUSTOM_PROTECTION_RULE"

    #: A constant which can be used with the operation_type property of a WorkRequest.
    #: This constant has a value of "DELETE_CUSTOM_PROTECTION_RULE"
    OPERATION_TYPE_DELETE_CUSTOM_PROTECTION_RULE = "DELETE_CUSTOM_PROTECTION_RULE"

    #: A constant which can be used with the status property of a WorkRequest.
    #: This constant has a value of "ACCEPTED"
    STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the status property of a WorkRequest.
    #: This constant has a value of "IN_PROGRESS"
    STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the status property of a WorkRequest.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    #: A constant which can be used with the status property of a WorkRequest.
    #: This constant has a value of "SUCCEEDED"
    STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the status property of a WorkRequest.
    #: This constant has a value of "CANCELING"
    STATUS_CANCELING = "CANCELING"

    #: A constant which can be used with the status property of a WorkRequest.
    #: This constant has a value of "CANCELED"
    STATUS_CANCELED = "CANCELED"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this WorkRequest.
        :type id: str

        :param operation_type:
            The value to assign to the operation_type property of this WorkRequest.
            Allowed values for this property are: "CREATE_WAAS_POLICY", "UPDATE_WAAS_POLICY", "DELETE_WAAS_POLICY", "CREATE_HTTP_REDIRECT", "UPDATE_HTTP_REDIRECT", "DELETE_HTTP_REDIRECT", "PURGE_WAAS_POLICY_CACHE", "CREATE_CUSTOM_PROTECTION_RULE", "UPDATE_CUSTOM_PROTECTION_RULE", "DELETE_CUSTOM_PROTECTION_RULE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation_type: str

        :param status:
            The value to assign to the status property of this WorkRequest.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param compartment_id:
            The value to assign to the compartment_id property of this WorkRequest.
        :type compartment_id: str

        :param resources:
            The value to assign to the resources property of this WorkRequest.
        :type resources: list[oci.waas.models.WorkRequestResource]

        :param percent_complete:
            The value to assign to the percent_complete property of this WorkRequest.
        :type percent_complete: int

        :param logs:
            The value to assign to the logs property of this WorkRequest.
        :type logs: list[oci.waas.models.WorkRequestLogEntry]

        :param errors:
            The value to assign to the errors property of this WorkRequest.
        :type errors: list[oci.waas.models.WorkRequestError]

        :param time_accepted:
            The value to assign to the time_accepted property of this WorkRequest.
        :type time_accepted: datetime

        :param time_started:
            The value to assign to the time_started property of this WorkRequest.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this WorkRequest.
        :type time_finished: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'operation_type': 'str',
            'status': 'str',
            'compartment_id': 'str',
            'resources': 'list[WorkRequestResource]',
            'percent_complete': 'int',
            'logs': 'list[WorkRequestLogEntry]',
            'errors': 'list[WorkRequestError]',
            'time_accepted': 'datetime',
            'time_started': 'datetime',
            'time_finished': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'operation_type': 'operationType',
            'status': 'status',
            'compartment_id': 'compartmentId',
            'resources': 'resources',
            'percent_complete': 'percentComplete',
            'logs': 'logs',
            'errors': 'errors',
            'time_accepted': 'timeAccepted',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished'
        }

        self._id = None
        self._operation_type = None
        self._status = None
        self._compartment_id = None
        self._resources = None
        self._percent_complete = None
        self._logs = None
        self._errors = None
        self._time_accepted = None
        self._time_started = None
        self._time_finished = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this WorkRequest.
        The `OCID`__ of the work request.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this WorkRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkRequest.
        The `OCID`__ of the work request.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this WorkRequest.
        :type: str
        """
        self._id = id

    @property
    def operation_type(self):
        """
        **[Required]** Gets the operation_type of this WorkRequest.
        A description of the operation requested by the work request.

        Allowed values for this property are: "CREATE_WAAS_POLICY", "UPDATE_WAAS_POLICY", "DELETE_WAAS_POLICY", "CREATE_HTTP_REDIRECT", "UPDATE_HTTP_REDIRECT", "DELETE_HTTP_REDIRECT", "PURGE_WAAS_POLICY_CACHE", "CREATE_CUSTOM_PROTECTION_RULE", "UPDATE_CUSTOM_PROTECTION_RULE", "DELETE_CUSTOM_PROTECTION_RULE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation_type of this WorkRequest.
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """
        Sets the operation_type of this WorkRequest.
        A description of the operation requested by the work request.


        :param operation_type: The operation_type of this WorkRequest.
        :type: str
        """
        allowed_values = ["CREATE_WAAS_POLICY", "UPDATE_WAAS_POLICY", "DELETE_WAAS_POLICY", "CREATE_HTTP_REDIRECT", "UPDATE_HTTP_REDIRECT", "DELETE_HTTP_REDIRECT", "PURGE_WAAS_POLICY_CACHE", "CREATE_CUSTOM_PROTECTION_RULE", "UPDATE_CUSTOM_PROTECTION_RULE", "DELETE_CUSTOM_PROTECTION_RULE"]
        if not value_allowed_none_or_none_sentinel(operation_type, allowed_values):
            operation_type = 'UNKNOWN_ENUM_VALUE'
        self._operation_type = operation_type

    @property
    def status(self):
        """
        **[Required]** Gets the status of this WorkRequest.
        The current status of the work request.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this WorkRequest.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this WorkRequest.
        The current status of the work request.


        :param status: The status of this WorkRequest.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this WorkRequest.
        The `OCID`__ of the compartment that contains the work request.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this WorkRequest.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this WorkRequest.
        The `OCID`__ of the compartment that contains the work request.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this WorkRequest.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def resources(self):
        """
        Gets the resources of this WorkRequest.
        The resources being used to complete the work request operation.


        :return: The resources of this WorkRequest.
        :rtype: list[oci.waas.models.WorkRequestResource]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """
        Sets the resources of this WorkRequest.
        The resources being used to complete the work request operation.


        :param resources: The resources of this WorkRequest.
        :type: list[oci.waas.models.WorkRequestResource]
        """
        self._resources = resources

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this WorkRequest.
        The percentage of work completed by the work request.


        :return: The percent_complete of this WorkRequest.
        :rtype: int
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this WorkRequest.
        The percentage of work completed by the work request.


        :param percent_complete: The percent_complete of this WorkRequest.
        :type: int
        """
        self._percent_complete = percent_complete

    @property
    def logs(self):
        """
        Gets the logs of this WorkRequest.
        The list of log entries from the work request workflow.


        :return: The logs of this WorkRequest.
        :rtype: list[oci.waas.models.WorkRequestLogEntry]
        """
        return self._logs

    @logs.setter
    def logs(self, logs):
        """
        Sets the logs of this WorkRequest.
        The list of log entries from the work request workflow.


        :param logs: The logs of this WorkRequest.
        :type: list[oci.waas.models.WorkRequestLogEntry]
        """
        self._logs = logs

    @property
    def errors(self):
        """
        Gets the errors of this WorkRequest.
        The list of errors that occurred while fulfilling the work request.


        :return: The errors of this WorkRequest.
        :rtype: list[oci.waas.models.WorkRequestError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this WorkRequest.
        The list of errors that occurred while fulfilling the work request.


        :param errors: The errors of this WorkRequest.
        :type: list[oci.waas.models.WorkRequestError]
        """
        self._errors = errors

    @property
    def time_accepted(self):
        """
        **[Required]** Gets the time_accepted of this WorkRequest.
        The date and time the work request was created, in the format defined by RFC3339.


        :return: The time_accepted of this WorkRequest.
        :rtype: datetime
        """
        return self._time_accepted

    @time_accepted.setter
    def time_accepted(self, time_accepted):
        """
        Sets the time_accepted of this WorkRequest.
        The date and time the work request was created, in the format defined by RFC3339.


        :param time_accepted: The time_accepted of this WorkRequest.
        :type: datetime
        """
        self._time_accepted = time_accepted

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this WorkRequest.
        The date and time the work request moved from the `ACCEPTED` state to the `IN_PROGRESS` state, expressed in RFC 3339 timestamp format.


        :return: The time_started of this WorkRequest.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this WorkRequest.
        The date and time the work request moved from the `ACCEPTED` state to the `IN_PROGRESS` state, expressed in RFC 3339 timestamp format.


        :param time_started: The time_started of this WorkRequest.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        **[Required]** Gets the time_finished of this WorkRequest.
        The date and time the work request was fulfilled or terminated, expressed in RFC 3339 timestamp format.


        :return: The time_finished of this WorkRequest.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this WorkRequest.
        The date and time the work request was fulfilled or terminated, expressed in RFC 3339 timestamp format.


        :param time_finished: The time_finished of this WorkRequest.
        :type: datetime
        """
        self._time_finished = time_finished

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDataAssetDetails(object):
    """
    Properties used in data asset update operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDataAssetDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateDataAssetDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateDataAssetDetails.
        :type description: str

        :param custom_property_members:
            The value to assign to the custom_property_members property of this UpdateDataAssetDetails.
        :type custom_property_members: list[oci.data_catalog.models.CustomPropertySetUsage]

        :param properties:
            The value to assign to the properties property of this UpdateDataAssetDetails.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'custom_property_members': 'list[CustomPropertySetUsage]',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'custom_property_members': 'customPropertyMembers',
            'properties': 'properties'
        }

        self._display_name = None
        self._description = None
        self._custom_property_members = None
        self._properties = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateDataAssetDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateDataAssetDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdateDataAssetDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdateDataAssetDetails.
        Detailed description of the data asset.


        :return: The description of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateDataAssetDetails.
        Detailed description of the data asset.


        :param description: The description of this UpdateDataAssetDetails.
        :type: str
        """
        self._description = description

    @property
    def custom_property_members(self):
        """
        Gets the custom_property_members of this UpdateDataAssetDetails.
        The list of customized properties along with the values for this object


        :return: The custom_property_members of this UpdateDataAssetDetails.
        :rtype: list[oci.data_catalog.models.CustomPropertySetUsage]
        """
        return self._custom_property_members

    @custom_property_members.setter
    def custom_property_members(self, custom_property_members):
        """
        Sets the custom_property_members of this UpdateDataAssetDetails.
        The list of customized properties along with the values for this object


        :param custom_property_members: The custom_property_members of this UpdateDataAssetDetails.
        :type: list[oci.data_catalog.models.CustomPropertySetUsage]
        """
        self._custom_property_members = custom_property_members

    @property
    def properties(self):
        """
        Gets the properties of this UpdateDataAssetDetails.
        A map of maps that contains the properties which are specific to the asset type. Each data asset type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        data assets have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"host\": \"host1\", \"port\": \"1521\", \"database\": \"orcl\"}}}`


        :return: The properties of this UpdateDataAssetDetails.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this UpdateDataAssetDetails.
        A map of maps that contains the properties which are specific to the asset type. Each data asset type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        data assets have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"host\": \"host1\", \"port\": \"1521\", \"database\": \"orcl\"}}}`


        :param properties: The properties of this UpdateDataAssetDetails.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SessionSummary(object):
    """
    Summary information for a bastion session resource.
    """

    #: A constant which can be used with the lifecycle_state property of a SessionSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SessionSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SessionSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a SessionSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a SessionSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new SessionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SessionSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this SessionSummary.
        :type display_name: str

        :param bastion_name:
            The value to assign to the bastion_name property of this SessionSummary.
        :type bastion_name: str

        :param bastion_id:
            The value to assign to the bastion_id property of this SessionSummary.
        :type bastion_id: str

        :param target_resource_details:
            The value to assign to the target_resource_details property of this SessionSummary.
        :type target_resource_details: oci.bastion.models.TargetResourceDetails

        :param time_created:
            The value to assign to the time_created property of this SessionSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this SessionSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SessionSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this SessionSummary.
        :type lifecycle_details: str

        :param session_ttl_in_seconds:
            The value to assign to the session_ttl_in_seconds property of this SessionSummary.
        :type session_ttl_in_seconds: int

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'bastion_name': 'str',
            'bastion_id': 'str',
            'target_resource_details': 'TargetResourceDetails',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'session_ttl_in_seconds': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'bastion_name': 'bastionName',
            'bastion_id': 'bastionId',
            'target_resource_details': 'targetResourceDetails',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'session_ttl_in_seconds': 'sessionTtlInSeconds'
        }

        self._id = None
        self._display_name = None
        self._bastion_name = None
        self._bastion_id = None
        self._target_resource_details = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._session_ttl_in_seconds = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SessionSummary.
        The unique identifier (OCID) of the session, which can't be changed after creation.


        :return: The id of this SessionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SessionSummary.
        The unique identifier (OCID) of the session, which can't be changed after creation.


        :param id: The id of this SessionSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this SessionSummary.
        The name of the session.


        :return: The display_name of this SessionSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SessionSummary.
        The name of the session.


        :param display_name: The display_name of this SessionSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def bastion_name(self):
        """
        **[Required]** Gets the bastion_name of this SessionSummary.
        The name of the bastion that is hosting this session.


        :return: The bastion_name of this SessionSummary.
        :rtype: str
        """
        return self._bastion_name

    @bastion_name.setter
    def bastion_name(self, bastion_name):
        """
        Sets the bastion_name of this SessionSummary.
        The name of the bastion that is hosting this session.


        :param bastion_name: The bastion_name of this SessionSummary.
        :type: str
        """
        self._bastion_name = bastion_name

    @property
    def bastion_id(self):
        """
        **[Required]** Gets the bastion_id of this SessionSummary.
        The unique identifier (OCID) of the bastion that is hosting this session.


        :return: The bastion_id of this SessionSummary.
        :rtype: str
        """
        return self._bastion_id

    @bastion_id.setter
    def bastion_id(self, bastion_id):
        """
        Sets the bastion_id of this SessionSummary.
        The unique identifier (OCID) of the bastion that is hosting this session.


        :param bastion_id: The bastion_id of this SessionSummary.
        :type: str
        """
        self._bastion_id = bastion_id

    @property
    def target_resource_details(self):
        """
        **[Required]** Gets the target_resource_details of this SessionSummary.

        :return: The target_resource_details of this SessionSummary.
        :rtype: oci.bastion.models.TargetResourceDetails
        """
        return self._target_resource_details

    @target_resource_details.setter
    def target_resource_details(self, target_resource_details):
        """
        Sets the target_resource_details of this SessionSummary.

        :param target_resource_details: The target_resource_details of this SessionSummary.
        :type: oci.bastion.models.TargetResourceDetails
        """
        self._target_resource_details = target_resource_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this SessionSummary.
        The time the session was created. Format is defined by `RFC3339`__.
        Example: `2020-01-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this SessionSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SessionSummary.
        The time the session was created. Format is defined by `RFC3339`__.
        Example: `2020-01-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this SessionSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this SessionSummary.
        The time the session was updated. Format is defined by `RFC3339`__.
        Example: `2020-01-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this SessionSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this SessionSummary.
        The time the session was updated. Format is defined by `RFC3339`__.
        Example: `2020-01-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this SessionSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this SessionSummary.
        The current state of the session.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SessionSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SessionSummary.
        The current state of the session.


        :param lifecycle_state: The lifecycle_state of this SessionSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this SessionSummary.
        A message describing the current session state in more detail.


        :return: The lifecycle_details of this SessionSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this SessionSummary.
        A message describing the current session state in more detail.


        :param lifecycle_details: The lifecycle_details of this SessionSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def session_ttl_in_seconds(self):
        """
        **[Required]** Gets the session_ttl_in_seconds of this SessionSummary.
        The amount of time the session can remain active.


        :return: The session_ttl_in_seconds of this SessionSummary.
        :rtype: int
        """
        return self._session_ttl_in_seconds

    @session_ttl_in_seconds.setter
    def session_ttl_in_seconds(self, session_ttl_in_seconds):
        """
        Sets the session_ttl_in_seconds of this SessionSummary.
        The amount of time the session can remain active.


        :param session_ttl_in_seconds: The session_ttl_in_seconds of this SessionSummary.
        :type: int
        """
        self._session_ttl_in_seconds = session_ttl_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PrivateEndpointDetails(object):
    """
    Optional parameters if a private stream pool is requested.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PrivateEndpointDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param subnet_id:
            The value to assign to the subnet_id property of this PrivateEndpointDetails.
        :type subnet_id: str

        :param private_endpoint_ip:
            The value to assign to the private_endpoint_ip property of this PrivateEndpointDetails.
        :type private_endpoint_ip: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this PrivateEndpointDetails.
        :type nsg_ids: list[str]

        """
        self.swagger_types = {
            'subnet_id': 'str',
            'private_endpoint_ip': 'str',
            'nsg_ids': 'list[str]'
        }

        self.attribute_map = {
            'subnet_id': 'subnetId',
            'private_endpoint_ip': 'privateEndpointIp',
            'nsg_ids': 'nsgIds'
        }

        self._subnet_id = None
        self._private_endpoint_ip = None
        self._nsg_ids = None

    @property
    def subnet_id(self):
        """
        Gets the subnet_id of this PrivateEndpointDetails.
        If specified, the stream pool will be private and only accessible from inside that subnet.
        Producing-to and consuming-from a stream inside a private stream pool can also only be done from inside the subnet.
        That value cannot be changed.


        :return: The subnet_id of this PrivateEndpointDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this PrivateEndpointDetails.
        If specified, the stream pool will be private and only accessible from inside that subnet.
        Producing-to and consuming-from a stream inside a private stream pool can also only be done from inside the subnet.
        That value cannot be changed.


        :param subnet_id: The subnet_id of this PrivateEndpointDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def private_endpoint_ip(self):
        """
        Gets the private_endpoint_ip of this PrivateEndpointDetails.
        The optional private IP you want to be associated with your private stream pool.
        That parameter can only be specified when the subnetId parameter is set. It cannot be changed.
        The private IP needs to be part of the CIDR range of the specified subnetId or the creation will fail.
        If not specified a random IP inside the subnet will be chosen.
        After the stream pool is created, a custom FQDN, pointing to this private IP, is created.
        The FQDN is then used to access the service instead of the private IP.


        :return: The private_endpoint_ip of this PrivateEndpointDetails.
        :rtype: str
        """
        return self._private_endpoint_ip

    @private_endpoint_ip.setter
    def private_endpoint_ip(self, private_endpoint_ip):
        """
        Sets the private_endpoint_ip of this PrivateEndpointDetails.
        The optional private IP you want to be associated with your private stream pool.
        That parameter can only be specified when the subnetId parameter is set. It cannot be changed.
        The private IP needs to be part of the CIDR range of the specified subnetId or the creation will fail.
        If not specified a random IP inside the subnet will be chosen.
        After the stream pool is created, a custom FQDN, pointing to this private IP, is created.
        The FQDN is then used to access the service instead of the private IP.


        :param private_endpoint_ip: The private_endpoint_ip of this PrivateEndpointDetails.
        :type: str
        """
        self._private_endpoint_ip = private_endpoint_ip

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this PrivateEndpointDetails.
        The optional list of network security groups to be used with the private endpoint of the stream pool.
        That value cannot be changed.


        :return: The nsg_ids of this PrivateEndpointDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this PrivateEndpointDetails.
        The optional list of network security groups to be used with the private endpoint of the stream pool.
        That value cannot be changed.


        :param nsg_ids: The nsg_ids of this PrivateEndpointDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_configuration_metric_group import HostConfigurationMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostMemoryConfiguration(HostConfigurationMetricGroup):
    """
    Memory Configuration metric for the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostMemoryConfiguration object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostMemoryConfiguration.metric_name` attribute
        of this class is ``HOST_MEMORY_CONFIGURATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostMemoryConfiguration.
            Allowed values for this property are: "HOST_PRODUCT", "HOST_RESOURCE_ALLOCATION", "HOST_MEMORY_CONFIGURATION", "HOST_HARDWARE_CONFIGURATION", "HOST_CPU_HARDWARE_CONFIGURATION", "HOST_NETWORK_CONFIGURATION", "HOST_ENTITES"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostMemoryConfiguration.
        :type time_collected: datetime

        :param page_size_in_kb:
            The value to assign to the page_size_in_kb property of this HostMemoryConfiguration.
        :type page_size_in_kb: float

        :param page_tables_in_kb:
            The value to assign to the page_tables_in_kb property of this HostMemoryConfiguration.
        :type page_tables_in_kb: float

        :param swap_total_in_kb:
            The value to assign to the swap_total_in_kb property of this HostMemoryConfiguration.
        :type swap_total_in_kb: float

        :param huge_page_size_in_kb:
            The value to assign to the huge_page_size_in_kb property of this HostMemoryConfiguration.
        :type huge_page_size_in_kb: float

        :param huge_pages_total:
            The value to assign to the huge_pages_total property of this HostMemoryConfiguration.
        :type huge_pages_total: int

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'page_size_in_kb': 'float',
            'page_tables_in_kb': 'float',
            'swap_total_in_kb': 'float',
            'huge_page_size_in_kb': 'float',
            'huge_pages_total': 'int'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'page_size_in_kb': 'pageSizeInKB',
            'page_tables_in_kb': 'pageTablesInKB',
            'swap_total_in_kb': 'swapTotalInKB',
            'huge_page_size_in_kb': 'hugePageSizeInKB',
            'huge_pages_total': 'hugePagesTotal'
        }

        self._metric_name = None
        self._time_collected = None
        self._page_size_in_kb = None
        self._page_tables_in_kb = None
        self._swap_total_in_kb = None
        self._huge_page_size_in_kb = None
        self._huge_pages_total = None
        self._metric_name = 'HOST_MEMORY_CONFIGURATION'

    @property
    def page_size_in_kb(self):
        """
        Gets the page_size_in_kb of this HostMemoryConfiguration.
        Page size in kilobytes


        :return: The page_size_in_kb of this HostMemoryConfiguration.
        :rtype: float
        """
        return self._page_size_in_kb

    @page_size_in_kb.setter
    def page_size_in_kb(self, page_size_in_kb):
        """
        Sets the page_size_in_kb of this HostMemoryConfiguration.
        Page size in kilobytes


        :param page_size_in_kb: The page_size_in_kb of this HostMemoryConfiguration.
        :type: float
        """
        self._page_size_in_kb = page_size_in_kb

    @property
    def page_tables_in_kb(self):
        """
        Gets the page_tables_in_kb of this HostMemoryConfiguration.
        Amount of memory used for page tables in kilobytes


        :return: The page_tables_in_kb of this HostMemoryConfiguration.
        :rtype: float
        """
        return self._page_tables_in_kb

    @page_tables_in_kb.setter
    def page_tables_in_kb(self, page_tables_in_kb):
        """
        Sets the page_tables_in_kb of this HostMemoryConfiguration.
        Amount of memory used for page tables in kilobytes


        :param page_tables_in_kb: The page_tables_in_kb of this HostMemoryConfiguration.
        :type: float
        """
        self._page_tables_in_kb = page_tables_in_kb

    @property
    def swap_total_in_kb(self):
        """
        Gets the swap_total_in_kb of this HostMemoryConfiguration.
        Amount of total swap space in kilobytes


        :return: The swap_total_in_kb of this HostMemoryConfiguration.
        :rtype: float
        """
        return self._swap_total_in_kb

    @swap_total_in_kb.setter
    def swap_total_in_kb(self, swap_total_in_kb):
        """
        Sets the swap_total_in_kb of this HostMemoryConfiguration.
        Amount of total swap space in kilobytes


        :param swap_total_in_kb: The swap_total_in_kb of this HostMemoryConfiguration.
        :type: float
        """
        self._swap_total_in_kb = swap_total_in_kb

    @property
    def huge_page_size_in_kb(self):
        """
        Gets the huge_page_size_in_kb of this HostMemoryConfiguration.
        Size of huge pages in kilobytes


        :return: The huge_page_size_in_kb of this HostMemoryConfiguration.
        :rtype: float
        """
        return self._huge_page_size_in_kb

    @huge_page_size_in_kb.setter
    def huge_page_size_in_kb(self, huge_page_size_in_kb):
        """
        Sets the huge_page_size_in_kb of this HostMemoryConfiguration.
        Size of huge pages in kilobytes


        :param huge_page_size_in_kb: The huge_page_size_in_kb of this HostMemoryConfiguration.
        :type: float
        """
        self._huge_page_size_in_kb = huge_page_size_in_kb

    @property
    def huge_pages_total(self):
        """
        Gets the huge_pages_total of this HostMemoryConfiguration.
        Total number of huge pages


        :return: The huge_pages_total of this HostMemoryConfiguration.
        :rtype: int
        """
        return self._huge_pages_total

    @huge_pages_total.setter
    def huge_pages_total(self, huge_pages_total):
        """
        Sets the huge_pages_total of this HostMemoryConfiguration.
        Total number of huge pages


        :param huge_pages_total: The huge_pages_total of this HostMemoryConfiguration.
        :type: int
        """
        self._huge_pages_total = huge_pages_total

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DecryptedData(object):
    """
    DecryptedData model.
    """

    #: A constant which can be used with the encryption_algorithm property of a DecryptedData.
    #: This constant has a value of "AES_256_GCM"
    ENCRYPTION_ALGORITHM_AES_256_GCM = "AES_256_GCM"

    #: A constant which can be used with the encryption_algorithm property of a DecryptedData.
    #: This constant has a value of "RSA_OAEP_SHA_1"
    ENCRYPTION_ALGORITHM_RSA_OAEP_SHA_1 = "RSA_OAEP_SHA_1"

    #: A constant which can be used with the encryption_algorithm property of a DecryptedData.
    #: This constant has a value of "RSA_OAEP_SHA_256"
    ENCRYPTION_ALGORITHM_RSA_OAEP_SHA_256 = "RSA_OAEP_SHA_256"

    def __init__(self, **kwargs):
        """
        Initializes a new DecryptedData object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param plaintext:
            The value to assign to the plaintext property of this DecryptedData.
        :type plaintext: str

        :param plaintext_checksum:
            The value to assign to the plaintext_checksum property of this DecryptedData.
        :type plaintext_checksum: str

        :param key_id:
            The value to assign to the key_id property of this DecryptedData.
        :type key_id: str

        :param key_version_id:
            The value to assign to the key_version_id property of this DecryptedData.
        :type key_version_id: str

        :param encryption_algorithm:
            The value to assign to the encryption_algorithm property of this DecryptedData.
            Allowed values for this property are: "AES_256_GCM", "RSA_OAEP_SHA_1", "RSA_OAEP_SHA_256", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type encryption_algorithm: str

        """
        self.swagger_types = {
            'plaintext': 'str',
            'plaintext_checksum': 'str',
            'key_id': 'str',
            'key_version_id': 'str',
            'encryption_algorithm': 'str'
        }

        self.attribute_map = {
            'plaintext': 'plaintext',
            'plaintext_checksum': 'plaintextChecksum',
            'key_id': 'keyId',
            'key_version_id': 'keyVersionId',
            'encryption_algorithm': 'encryptionAlgorithm'
        }

        self._plaintext = None
        self._plaintext_checksum = None
        self._key_id = None
        self._key_version_id = None
        self._encryption_algorithm = None

    @property
    def plaintext(self):
        """
        **[Required]** Gets the plaintext of this DecryptedData.
        The decrypted data, expressed as a base64-encoded value.


        :return: The plaintext of this DecryptedData.
        :rtype: str
        """
        return self._plaintext

    @plaintext.setter
    def plaintext(self, plaintext):
        """
        Sets the plaintext of this DecryptedData.
        The decrypted data, expressed as a base64-encoded value.


        :param plaintext: The plaintext of this DecryptedData.
        :type: str
        """
        self._plaintext = plaintext

    @property
    def plaintext_checksum(self):
        """
        **[Required]** Gets the plaintext_checksum of this DecryptedData.
        The checksum of the decrypted data.


        :return: The plaintext_checksum of this DecryptedData.
        :rtype: str
        """
        return self._plaintext_checksum

    @plaintext_checksum.setter
    def plaintext_checksum(self, plaintext_checksum):
        """
        Sets the plaintext_checksum of this DecryptedData.
        The checksum of the decrypted data.


        :param plaintext_checksum: The plaintext_checksum of this DecryptedData.
        :type: str
        """
        self._plaintext_checksum = plaintext_checksum

    @property
    def key_id(self):
        """
        Gets the key_id of this DecryptedData.
        The OCID of the key used to encrypt the ciphertext.


        :return: The key_id of this DecryptedData.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this DecryptedData.
        The OCID of the key used to encrypt the ciphertext.


        :param key_id: The key_id of this DecryptedData.
        :type: str
        """
        self._key_id = key_id

    @property
    def key_version_id(self):
        """
        Gets the key_version_id of this DecryptedData.
        The OCID of the key version used to encrypt the ciphertext.


        :return: The key_version_id of this DecryptedData.
        :rtype: str
        """
        return self._key_version_id

    @key_version_id.setter
    def key_version_id(self, key_version_id):
        """
        Sets the key_version_id of this DecryptedData.
        The OCID of the key version used to encrypt the ciphertext.


        :param key_version_id: The key_version_id of this DecryptedData.
        :type: str
        """
        self._key_version_id = key_version_id

    @property
    def encryption_algorithm(self):
        """
        Gets the encryption_algorithm of this DecryptedData.
        The encryption algorithm to use to encrypt and decrypt data with a customer-managed key
        `AES_256_GCM` indicates that the key is a symmetric key that uses the Advanced Encryption Standard (AES) algorithm and
        that the mode of encryption is the Galois/Counter Mode (GCM). `RSA_OAEP_SHA_1` indicates that the
        key is an asymmetric key that uses the RSA encryption algorithm and uses Optimal Asymmetric Encryption Padding (OAEP).
        `RSA_OAEP_SHA_256` indicates that the key is an asymmetric key that uses the RSA encryption algorithm with a SHA-256 hash
        and uses OAEP.

        Allowed values for this property are: "AES_256_GCM", "RSA_OAEP_SHA_1", "RSA_OAEP_SHA_256", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The encryption_algorithm of this DecryptedData.
        :rtype: str
        """
        return self._encryption_algorithm

    @encryption_algorithm.setter
    def encryption_algorithm(self, encryption_algorithm):
        """
        Sets the encryption_algorithm of this DecryptedData.
        The encryption algorithm to use to encrypt and decrypt data with a customer-managed key
        `AES_256_GCM` indicates that the key is a symmetric key that uses the Advanced Encryption Standard (AES) algorithm and
        that the mode of encryption is the Galois/Counter Mode (GCM). `RSA_OAEP_SHA_1` indicates that the
        key is an asymmetric key that uses the RSA encryption algorithm and uses Optimal Asymmetric Encryption Padding (OAEP).
        `RSA_OAEP_SHA_256` indicates that the key is an asymmetric key that uses the RSA encryption algorithm with a SHA-256 hash
        and uses OAEP.


        :param encryption_algorithm: The encryption_algorithm of this DecryptedData.
        :type: str
        """
        allowed_values = ["AES_256_GCM", "RSA_OAEP_SHA_1", "RSA_OAEP_SHA_256"]
        if not value_allowed_none_or_none_sentinel(encryption_algorithm, allowed_values):
            encryption_algorithm = 'UNKNOWN_ENUM_VALUE'
        self._encryption_algorithm = encryption_algorithm

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateLogAnalyticsEntityDetails(object):
    """
    Details of log analytics entity to be updated.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateLogAnalyticsEntityDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this UpdateLogAnalyticsEntityDetails.
        :type name: str

        :param management_agent_id:
            The value to assign to the management_agent_id property of this UpdateLogAnalyticsEntityDetails.
        :type management_agent_id: str

        :param timezone_region:
            The value to assign to the timezone_region property of this UpdateLogAnalyticsEntityDetails.
        :type timezone_region: str

        :param hostname:
            The value to assign to the hostname property of this UpdateLogAnalyticsEntityDetails.
        :type hostname: str

        :param properties:
            The value to assign to the properties property of this UpdateLogAnalyticsEntityDetails.
        :type properties: dict(str, str)

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateLogAnalyticsEntityDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateLogAnalyticsEntityDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'name': 'str',
            'management_agent_id': 'str',
            'timezone_region': 'str',
            'hostname': 'str',
            'properties': 'dict(str, str)',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'name': 'name',
            'management_agent_id': 'managementAgentId',
            'timezone_region': 'timezoneRegion',
            'hostname': 'hostname',
            'properties': 'properties',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._name = None
        self._management_agent_id = None
        self._timezone_region = None
        self._hostname = None
        self._properties = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def name(self):
        """
        Gets the name of this UpdateLogAnalyticsEntityDetails.
        Log analytics entity name.


        :return: The name of this UpdateLogAnalyticsEntityDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateLogAnalyticsEntityDetails.
        Log analytics entity name.


        :param name: The name of this UpdateLogAnalyticsEntityDetails.
        :type: str
        """
        self._name = name

    @property
    def management_agent_id(self):
        """
        Gets the management_agent_id of this UpdateLogAnalyticsEntityDetails.
        The OCID of the Management Agent.


        :return: The management_agent_id of this UpdateLogAnalyticsEntityDetails.
        :rtype: str
        """
        return self._management_agent_id

    @management_agent_id.setter
    def management_agent_id(self, management_agent_id):
        """
        Sets the management_agent_id of this UpdateLogAnalyticsEntityDetails.
        The OCID of the Management Agent.


        :param management_agent_id: The management_agent_id of this UpdateLogAnalyticsEntityDetails.
        :type: str
        """
        self._management_agent_id = management_agent_id

    @property
    def timezone_region(self):
        """
        Gets the timezone_region of this UpdateLogAnalyticsEntityDetails.
        The timezone region of the log analytics entity.


        :return: The timezone_region of this UpdateLogAnalyticsEntityDetails.
        :rtype: str
        """
        return self._timezone_region

    @timezone_region.setter
    def timezone_region(self, timezone_region):
        """
        Sets the timezone_region of this UpdateLogAnalyticsEntityDetails.
        The timezone region of the log analytics entity.


        :param timezone_region: The timezone_region of this UpdateLogAnalyticsEntityDetails.
        :type: str
        """
        self._timezone_region = timezone_region

    @property
    def hostname(self):
        """
        Gets the hostname of this UpdateLogAnalyticsEntityDetails.
        The hostname where the entity represented here is actually present. This would be the output one would get if
        they run `echo $HOSTNAME` on Linux or an equivalent OS command. This may be different from
        management agents host since logs may be collected remotely.


        :return: The hostname of this UpdateLogAnalyticsEntityDetails.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this UpdateLogAnalyticsEntityDetails.
        The hostname where the entity represented here is actually present. This would be the output one would get if
        they run `echo $HOSTNAME` on Linux or an equivalent OS command. This may be different from
        management agents host since logs may be collected remotely.


        :param hostname: The hostname of this UpdateLogAnalyticsEntityDetails.
        :type: str
        """
        self._hostname = hostname

    @property
    def properties(self):
        """
        Gets the properties of this UpdateLogAnalyticsEntityDetails.
        The name/value pairs for parameter values to be used in file patterns specified in log sources.


        :return: The properties of this UpdateLogAnalyticsEntityDetails.
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this UpdateLogAnalyticsEntityDetails.
        The name/value pairs for parameter values to be used in file patterns specified in log sources.


        :param properties: The properties of this UpdateLogAnalyticsEntityDetails.
        :type: dict(str, str)
        """
        self._properties = properties

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateLogAnalyticsEntityDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateLogAnalyticsEntityDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateLogAnalyticsEntityDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateLogAnalyticsEntityDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateLogAnalyticsEntityDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateLogAnalyticsEntityDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateLogAnalyticsEntityDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateLogAnalyticsEntityDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDataMaskRuleDetails(object):
    """
    The information to be updated.
    """

    #: A constant which can be used with the data_mask_categories property of a UpdateDataMaskRuleDetails.
    #: This constant has a value of "ACTOR"
    DATA_MASK_CATEGORIES_ACTOR = "ACTOR"

    #: A constant which can be used with the data_mask_categories property of a UpdateDataMaskRuleDetails.
    #: This constant has a value of "PII"
    DATA_MASK_CATEGORIES_PII = "PII"

    #: A constant which can be used with the data_mask_categories property of a UpdateDataMaskRuleDetails.
    #: This constant has a value of "PHI"
    DATA_MASK_CATEGORIES_PHI = "PHI"

    #: A constant which can be used with the data_mask_categories property of a UpdateDataMaskRuleDetails.
    #: This constant has a value of "FINANCIAL"
    DATA_MASK_CATEGORIES_FINANCIAL = "FINANCIAL"

    #: A constant which can be used with the data_mask_categories property of a UpdateDataMaskRuleDetails.
    #: This constant has a value of "LOCATION"
    DATA_MASK_CATEGORIES_LOCATION = "LOCATION"

    #: A constant which can be used with the data_mask_categories property of a UpdateDataMaskRuleDetails.
    #: This constant has a value of "CUSTOM"
    DATA_MASK_CATEGORIES_CUSTOM = "CUSTOM"

    #: A constant which can be used with the data_mask_rule_status property of a UpdateDataMaskRuleDetails.
    #: This constant has a value of "ENABLED"
    DATA_MASK_RULE_STATUS_ENABLED = "ENABLED"

    #: A constant which can be used with the data_mask_rule_status property of a UpdateDataMaskRuleDetails.
    #: This constant has a value of "DISABLED"
    DATA_MASK_RULE_STATUS_DISABLED = "DISABLED"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDataMaskRuleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateDataMaskRuleDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this UpdateDataMaskRuleDetails.
        :type compartment_id: str

        :param iam_group_id:
            The value to assign to the iam_group_id property of this UpdateDataMaskRuleDetails.
        :type iam_group_id: str

        :param target_selected:
            The value to assign to the target_selected property of this UpdateDataMaskRuleDetails.
        :type target_selected: oci.cloud_guard.models.TargetSelected

        :param data_mask_categories:
            The value to assign to the data_mask_categories property of this UpdateDataMaskRuleDetails.
            Allowed values for items in this list are: "ACTOR", "PII", "PHI", "FINANCIAL", "LOCATION", "CUSTOM"
        :type data_mask_categories: list[str]

        :param data_mask_rule_status:
            The value to assign to the data_mask_rule_status property of this UpdateDataMaskRuleDetails.
            Allowed values for this property are: "ENABLED", "DISABLED"
        :type data_mask_rule_status: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateDataMaskRuleDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateDataMaskRuleDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'iam_group_id': 'str',
            'target_selected': 'TargetSelected',
            'data_mask_categories': 'list[str]',
            'data_mask_rule_status': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'iam_group_id': 'iamGroupId',
            'target_selected': 'targetSelected',
            'data_mask_categories': 'dataMaskCategories',
            'data_mask_rule_status': 'dataMaskRuleStatus',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._iam_group_id = None
        self._target_selected = None
        self._data_mask_categories = None
        self._data_mask_rule_status = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateDataMaskRuleDetails.
        Data Mask Rule Name


        :return: The display_name of this UpdateDataMaskRuleDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateDataMaskRuleDetails.
        Data Mask Rule Name


        :param display_name: The display_name of this UpdateDataMaskRuleDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this UpdateDataMaskRuleDetails.
        Compartment Identifier where the resource is created


        :return: The compartment_id of this UpdateDataMaskRuleDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this UpdateDataMaskRuleDetails.
        Compartment Identifier where the resource is created


        :param compartment_id: The compartment_id of this UpdateDataMaskRuleDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def iam_group_id(self):
        """
        Gets the iam_group_id of this UpdateDataMaskRuleDetails.
        IAM Group id associated with the data mask rule


        :return: The iam_group_id of this UpdateDataMaskRuleDetails.
        :rtype: str
        """
        return self._iam_group_id

    @iam_group_id.setter
    def iam_group_id(self, iam_group_id):
        """
        Sets the iam_group_id of this UpdateDataMaskRuleDetails.
        IAM Group id associated with the data mask rule


        :param iam_group_id: The iam_group_id of this UpdateDataMaskRuleDetails.
        :type: str
        """
        self._iam_group_id = iam_group_id

    @property
    def target_selected(self):
        """
        Gets the target_selected of this UpdateDataMaskRuleDetails.

        :return: The target_selected of this UpdateDataMaskRuleDetails.
        :rtype: oci.cloud_guard.models.TargetSelected
        """
        return self._target_selected

    @target_selected.setter
    def target_selected(self, target_selected):
        """
        Sets the target_selected of this UpdateDataMaskRuleDetails.

        :param target_selected: The target_selected of this UpdateDataMaskRuleDetails.
        :type: oci.cloud_guard.models.TargetSelected
        """
        self._target_selected = target_selected

    @property
    def data_mask_categories(self):
        """
        Gets the data_mask_categories of this UpdateDataMaskRuleDetails.
        Data Mask Categories

        Allowed values for items in this list are: "ACTOR", "PII", "PHI", "FINANCIAL", "LOCATION", "CUSTOM"


        :return: The data_mask_categories of this UpdateDataMaskRuleDetails.
        :rtype: list[str]
        """
        return self._data_mask_categories

    @data_mask_categories.setter
    def data_mask_categories(self, data_mask_categories):
        """
        Sets the data_mask_categories of this UpdateDataMaskRuleDetails.
        Data Mask Categories


        :param data_mask_categories: The data_mask_categories of this UpdateDataMaskRuleDetails.
        :type: list[str]
        """
        allowed_values = ["ACTOR", "PII", "PHI", "FINANCIAL", "LOCATION", "CUSTOM"]

        if data_mask_categories and data_mask_categories is not NONE_SENTINEL:
            for value in data_mask_categories:
                if not value_allowed_none_or_none_sentinel(value, allowed_values):
                    raise ValueError(
                        "Invalid value for `data_mask_categories`, must be None or one of {0}"
                        .format(allowed_values)
                    )
        self._data_mask_categories = data_mask_categories

    @property
    def data_mask_rule_status(self):
        """
        Gets the data_mask_rule_status of this UpdateDataMaskRuleDetails.
        The status of the dataMaskRule.

        Allowed values for this property are: "ENABLED", "DISABLED"


        :return: The data_mask_rule_status of this UpdateDataMaskRuleDetails.
        :rtype: str
        """
        return self._data_mask_rule_status

    @data_mask_rule_status.setter
    def data_mask_rule_status(self, data_mask_rule_status):
        """
        Sets the data_mask_rule_status of this UpdateDataMaskRuleDetails.
        The status of the dataMaskRule.


        :param data_mask_rule_status: The data_mask_rule_status of this UpdateDataMaskRuleDetails.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(data_mask_rule_status, allowed_values):
            raise ValueError(
                "Invalid value for `data_mask_rule_status`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._data_mask_rule_status = data_mask_rule_status

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateDataMaskRuleDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateDataMaskRuleDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateDataMaskRuleDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateDataMaskRuleDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateDataMaskRuleDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateDataMaskRuleDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateDataMaskRuleDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateDataMaskRuleDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
